@@ -25,11 +25,14 @@
 
 #include <ext/standard/php_var.h>
 #include <ext/standard/sha1.h>
+#if PHP_MAJOR_VERSION < 7
+#include <ext/standard/php_smart_str.h>
+#else
 #include <zend_smart_str.h>
+#endif
 #include <ext/spl/spl_exceptions.h>
 #include <zend_exceptions.h>
 
-#include <grpc/credentials.h>
 #include <grpc/grpc_security.h>
 #include <grpc/support/alloc.h>
 #include <grpc/support/log.h>
@@ -242,12 +245,11 @@ void create_channel(
     grpc_channel_args args,
     wrapped_grpc_channel_credentials *creds) {
   if (creds == NULL) {
-    grpc_channel_credentials* insecure_creds = grpc_insecure_credentials_create();
-    channel->wrapper->wrapped = grpc_channel_create(target, insecure_creds, &args);
-    grpc_channel_credentials_release(insecure_creds);
+    channel->wrapper->wrapped = grpc_insecure_channel_create(target, &args,
+                                                             NULL);
   } else {
     channel->wrapper->wrapped =
-        grpc_channel_create(target, creds->wrapped, &args);
+        grpc_secure_channel_create(creds->wrapped, target, &args, NULL);
   }
   // There is an Grpc\Channel object refer to it.
   php_grpc_channel_ref(channel->wrapper);
@@ -272,16 +274,12 @@ void create_and_add_channel_to_persistent_list(
       // If no channel can be deleted from the persistent map,
       // do not persist this one.
       create_channel(channel, target, args, creds);
-      grpc_absl_log_str(GPR_INFO,
-        "[Warning] The number of channel for the target is maxed out bounded."
-        " Target will not be persisted. Target : ",
-        target);
-      grpc_absl_log_int(GPR_INFO,
-        "[Warning] Target upper bound: ",
-        target_bound_status->upper_bound);
-      grpc_absl_log_int(GPR_INFO,
-        "[Warning] Current size: ",
-        target_bound_status->current_count);
+      gpr_log(GPR_INFO, "[Warning] The number of channel for the"
+                 " target %s is maxed out bounded.\n", target);
+      gpr_log(GPR_INFO, "[Warning] Target upper bound: %d. Current size: %d.\n",
+                 target_bound_status->upper_bound,
+                 target_bound_status->current_count);
+      gpr_log(GPR_INFO, "[Warning] Target %s will not be persisted.\n", target);
       return;
     }
   }
@@ -795,12 +793,14 @@ GRPC_STARTUP_FUNCTION(channel) {
   gpr_mu_init(&global_persistent_list_mu);
   le_plink = zend_register_list_destructors_ex(
       NULL, php_grpc_channel_plink_dtor, "Persistent Channel", module_number);
-  ZEND_HASH_INIT(&grpc_persistent_list, 20, EG(persistent_list).pDestructor, 1);
+  zend_hash_init_ex(&grpc_persistent_list, 20, NULL,
+                    EG(persistent_list).pDestructor, 1, 0);
   // Register the target->upper_bound map.
   le_bound = zend_register_list_destructors_ex(
       NULL, php_grpc_target_bound_dtor, "Target Bound", module_number);
-  ZEND_HASH_INIT(&grpc_target_upper_bound_map, 20, EG(persistent_list).pDestructor, 1);
-  
+  zend_hash_init_ex(&grpc_target_upper_bound_map, 20, NULL,
+                    EG(persistent_list).pDestructor, 1, 0);
+
   PHP_GRPC_INIT_HANDLER(wrapped_grpc_channel, channel_ce_handlers);
   return SUCCESS;
 }
